import {
  fetchConsumeList,
  fetchReportList,
  fetchTitleList,
} from '@/api/dashboard/dashboard';

const GET_CONSUME_DATA = 'GET_CONSUME_DATA';
const GET_REPORT_DATA = 'GET_REPORT_DATA';
const GET_TITLE_DATA = 'GET_TITLE_DATA';
const GET_PERCENT_DATA = 'GET_PERCENT_DATA';
const GET_EUIPMENT_DATA = 'GET_EUIPMENT_DATA';

const state = () => ({
  consume: {
    consumeHardVos: [],
    list: [],
    percentList: [],
  },
  report: {
    year: new Date().getFullYear(),
    month: new Date().getMonth() + 1,
    registePerDay: [],
    registePerMonth: [],
    activeUser: [],
  },
  title: {
    activeCount: 0,
    countArea: 0,
    countCustomer: 0,
  },
});

const getters = {
  reportYear: state => state.report.year,
  reportMonth: state => state.report.month,
  registePerDay: state => state.report.registePerDay,
  registePerMonth: state => state.report.registePerMonth,
  activeUser: state => state.report.activeUser,
  titleData: state => state.title,
  consumeHardVos: state => state.consume.consumeHardVos,
  campusRankList: state => state.consume.list,
  seviceRatioList: state => state.consume.percentList,
};

const actions = {
  fetchConsumeList({ commit }, entity) {
    return fetchConsumeList({
      params: {
        ...entity,
      },
    }).then(res => {
      let list = res.data;
      if (entity && entity.updatePercentList) {
        commit(GET_PERCENT_DATA, list);
        return;
      }
      if (entity && entity.updateEuipmentList) {
        commit(GET_EUIPMENT_DATA, list);
        return;
      }
      commit(GET_CONSUME_DATA, list);
    });
  },
  fetchReportList({ commit }, entity) {
    return fetchReportList({
      params: {
        ...entity,
      },
    }).then(res => {
      let list = res.data;
      commit(GET_REPORT_DATA, list);
    });
  },
  fetchTitleList({ commit }) {
    return fetchTitleList().then(res => {
      let data = res.data;
      commit(GET_TITLE_DATA, data);
    });
  },
};

const mutations = {
  [GET_CONSUME_DATA]: (state, data) => {
    state.consume.consumeHardVos = data.consumeHardVos;
    state.consume.list = data.list;
    state.consume.percentList = data.percentList;
  },
  [GET_PERCENT_DATA]: (state, data) => {
    state.consume.percentList = data.percentList;
  },
  [GET_EUIPMENT_DATA]: (state, data) => {
    state.consume.consumeHardVos = data.consumeHardVos;
  },
  [GET_REPORT_DATA]: (state, data) => {
    state.report.year = data.year;
    state.report.month = data.month;
    let dayList = new Array(31).fill({ count: 0 });
    dayList = dayList.map((v, idx) => ({ ...v, days: idx + 1 }));
    data.dayVos.map(val => {
      let idx = Number(val.days.substr(-2)) - 1;
      dayList[idx].count = val.count;
    });
    state.report.registePerDay = dayList;
    state.report.registePerMonth = data.list;
    state.report.activeUser = data.listCount;
  },
  [GET_TITLE_DATA](state, data) {
    state.title = data;
  },
};

export default {
  namespaced: true,
  state,
  getters,
  actions,
  mutations,
};
